@@ -1,6 +1,4 @@
-context("evaluate_orig")
-
-test_that("works", {
+test_that("evaluate_orig works", {
   set.seed(42)
   samples <- 10
   m <- matrix(rnorm(samples), nrow = samples)
@@ -8,7 +6,7 @@ test_that("works", {
   expect_error(e <- evaluate_orig(m), "is not TRUE")
 
   colnames(m) <- "Age"
-  e <- evaluate_orig( m)
+  e <- evaluate_orig(m)
   expect_equal(e["na", "Age"], 5L)
   expect_equal(e["entropy", "Age"], 0)
   expect_equal(e["mean", "Age"], mean(m[, 1], na.rm = TRUE))
